@@ -1,7 +1,7 @@
 package TableData::Object::aoaos;
 
-our $DATE = '2015-11-02'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-01-11'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -64,6 +64,50 @@ sub rows_as_aohos {
     $rows;
 }
 
+sub _const_col {
+    my ($self, $which) = @_;
+
+    my $res = [];
+  COL:
+    for my $colname (keys %{$self->{cols_by_name}}) {
+        my $colidx = $self->{cols_by_name}{$colname};
+        my $i = -1;
+        my $val;
+        for my $row (@{$self->{data}}) {
+            next COL unless $#{$row} >= $colidx;
+            $i++;
+            if ($i == 0) {
+                $val = $row->[$colidx];
+            } else {
+                next COL unless
+                    (!defined($val) && !defined($row->[$colidx])) ||
+                    ( defined($val) &&  defined($row->[$colidx]) && $val eq $row->[$colidx]);
+            }
+        }
+        if ($which eq 'name') {
+            push @$res, $colname;
+        } else {
+            push @$res, $colidx;
+        }
+    }
+
+    if ($which eq 'name') {
+        return [sort {$a cmp $b} @$res];
+    } else {
+        return [sort {$a <=> $b} @$res];
+    }
+}
+
+sub const_col_names {
+    my $self = shift;
+    $self->_const_col('name');
+}
+
+sub const_col_idxs {
+    my $self = shift;
+    $self->_const_col('idx');
+}
+
 1;
 # ABSTRACT: Manipulate array of arrays-of-scalars via table object
 
@@ -79,7 +123,7 @@ TableData::Object::aoaos - Manipulate array of arrays-of-scalars via table objec
 
 =head1 VERSION
 
-This document describes version 0.06 of TableData::Object::aoaos (from Perl distribution TableData-Object), released on 2015-11-02.
+This document describes version 0.07 of TableData::Object::aoaos (from Perl distribution TableData-Object), released on 2016-01-11.
 
 =head1 SYNOPSIS
 
@@ -110,7 +154,22 @@ array-of-scalars will determine the number of columns.
 
 =head1 METHODS
 
-See L<TableData::Object::Base>.
+See L<TableData::Object::Base>. Additional methods include:
+
+=head2 const_col_names => arrayref
+
+Return names of columns that exist in all arrays with the same value. Example:
+
+ # data: [[1,2], [2,2,3], [1,2,3]]
+ $td->const_col_names; # ['column1'], 'column0' has a different value in 2nd array, 'column2' doesn't exist in all rows
+
+=head2 const_col_idxs => arrayref
+
+Just like C<const_col_names> except that it will return column indexes instead
+of names:
+
+ # data: [[1,2], [2,2,3], [1,2,3]]
+ $td->const_col_idxs; # [1]
 
 =head1 HOMEPAGE
 
@@ -118,7 +177,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/TableData-
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-TableData-Object>.
+Source repository is at L<https://github.com/perlancar/perl-TableData-Object>.
 
 =head1 BUGS
 
@@ -134,7 +193,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
