@@ -1,7 +1,7 @@
 package TableData::Object::aohos;
 
-our $DATE = '2015-11-02'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-01-11'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -68,6 +68,30 @@ sub rows_as_aohos {
     $self->{data};
 }
 
+sub const_col_names {
+    my $self = shift;
+
+    my $res = [];
+  COL:
+    for my $col (sort keys %{$self->{cols_by_name}}) {
+        my $i = -1;
+        my $val;
+        for my $row (@{$self->{data}}) {
+            next COL unless exists $row->{$col};
+            $i++;
+            if ($i == 0) {
+                $val = $row->{$col};
+            } else {
+                next COL unless
+                    (!defined($val) && !defined($row->{$col})) ||
+                    ( defined($val) &&  defined($row->{$col}) && $val eq $row->{$col});
+            }
+        }
+        push @$res, $col;
+    }
+    $res;
+}
+
 1;
 # ABSTRACT: Manipulate array of hashes-of-scalars via table object
 
@@ -83,7 +107,7 @@ TableData::Object::aohos - Manipulate array of hashes-of-scalars via table objec
 
 =head1 VERSION
 
-This document describes version 0.06 of TableData::Object::aohos (from Perl distribution TableData-Object), released on 2015-11-02.
+This document describes version 0.07 of TableData::Object::aohos (from Perl distribution TableData-Object), released on 2016-01-11.
 
 =head1 SYNOPSIS
 
@@ -113,7 +137,14 @@ The table will have columns from all the hashes' keys.
 
 =head1 METHODS
 
-See L<TableData::Object::Base>.
+See L<TableData::Object::Base>. Additional methods include:
+
+=head2 const_col_names => arrayref
+
+Return names of columns that exist in all hashes with the same value. Example:
+
+ # data: [{a=>1, b=>2}, {a=>2, b=>2, c=>3}, {a=>1, b=>2, c=>3}]
+ $td->const_col_names; # ['b'], 'a' has a different value in 2nd hash, 'c' doesn't exist in all hashes
 
 =head1 HOMEPAGE
 
@@ -121,7 +152,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/TableData-
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-TableData-Object>.
+Source repository is at L<https://github.com/perlancar/perl-TableData-Object>.
 
 =head1 BUGS
 
@@ -137,7 +168,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
